@@ -9,9 +9,14 @@ my %classes = (
     Address       => 'addresses',
     Attribute     => 'attributes',
     Country       => 'countries',
+    Inventory     => 'inventory',
+    Media         => 'media',
+    MessageType   => 'message_types',
+    Navigation    => 'navigation',
+    Order         => 'orders',
+    PriceModifier => 'price_modifiers',
     Product       => 'products',
     Role          => 'roles',
-    PriceModifier => 'price_modifiers',
     State         => 'states',
     Tax           => 'taxes',
     User          => 'users',
@@ -26,39 +31,77 @@ test 'initial environment' => sub {
 
     my $self = shift;
 
-    cmp_ok( $self->schema->resultset('Address')->count, '==', 0,
+    cmp_ok( $self->ic6s_schema->resultset('Address')->count, '==', 0,
         "no addresses" );
 
-    cmp_ok( $self->schema->resultset('Attribute')->count, '==', 0,
+    cmp_ok( $self->ic6s_schema->resultset('Attribute')->count, '==', 0,
         "no attributes" );
 
-    cmp_ok( $self->schema->resultset('Country')->count, '>=', 250,
+    cmp_ok( $self->ic6s_schema->resultset('Country')->count, '>=', 250,
         "at least 250 countries" );
 
-    cmp_ok( $self->schema->resultset('Product')->count, '==', 0,
+    cmp_ok( $self->ic6s_schema->resultset('Inventory')->count, '==', 0,
+        "no inventory" );
+
+    cmp_ok( $self->ic6s_schema->resultset('Media')->count, '==', 0,
+        "no media" );
+
+    cmp_ok( $self->ic6s_schema->resultset('MediaDisplay')->count, '==', 0,
+        "no media displays" );
+
+    cmp_ok( $self->ic6s_schema->resultset('MediaProduct')->count, '==', 0,
+        "no media product rows" );
+
+    cmp_ok( $self->ic6s_schema->resultset('MediaType')->count, '==', 0,
+        "no media types" );
+
+    cmp_ok( $self->ic6s_schema->resultset('MessageType')->count,
+        '==', 3, "3 message_types" );
+
+    cmp_ok( $self->ic6s_schema->resultset('Navigation')->count, '==', 0,
+        "no navigation rows" );
+
+    cmp_ok( $self->ic6s_schema->resultset('PriceModifier')->count, '==', 0,
+        "no price_modifiers" );
+
+    cmp_ok( $self->ic6s_schema->resultset('Product')->count, '==', 0,
         "no products" );
 
-    cmp_ok( $self->schema->resultset('Role')->count, '==', 3, "3 roles" );
+    cmp_ok( $self->ic6s_schema->resultset('Role')->count, '==', 3, "3 roles" );
 
-    cmp_ok( $self->schema->resultset('State')->count, '>=', 64,
+    cmp_ok( $self->ic6s_schema->resultset('State')->count, '>=', 64,
         "at least 64 states" );
 
-    cmp_ok( $self->schema->resultset('Tax')->count, '==', 0, "0 taxes" );
+    cmp_ok( $self->ic6s_schema->resultset('Tax')->count, '==', 0, "0 taxes" );
 
-    cmp_ok( $self->schema->resultset('User')->count, '==', 0, "no users" );
+    cmp_ok( $self->ic6s_schema->resultset('User')->count, '==', 0, "no users" );
 
-    cmp_ok( $self->schema->resultset('Zone')->count, '==', 317,
+    cmp_ok( $self->ic6s_schema->resultset('Zone')->count, '==', 317,
         "at least 317 zones" );
 
     foreach my $class ( sort keys %classes ) {
         my $predicate = "has_$classes{$class}";
         ok( !$self->$predicate, "$predicate is false" );
     }
+
+    lives_ok( sub { $self->load_all_fixtures }, "load_all_fixtures" );
+
+    foreach my $class ( sort keys %classes ) {
+        my $predicate = "has_$classes{$class}";
+        ok( $self->$predicate, "$predicate is true" );
+    }
+
+    lives_ok( sub { $self->clear_all_fixtures }, "clear_all_fixtures" );
+
+    foreach my $class ( sort keys %classes ) {
+        my $predicate = "has_$classes{$class}";
+        ok( !$self->$predicate, "$predicate is false" );
+    }
 };
 
 test 'countries' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     # loaded on $schema->deploy so clear before testing
     lives_ok( sub { $self->clear_countries }, "clear_countries" );
@@ -73,7 +116,7 @@ test 'countries' => sub {
 
 test 'states' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     # loaded on $schema->deploy so clear before testing
     lives_ok( sub { $self->clear_states }, "clear_states" );
@@ -92,7 +135,7 @@ test 'states' => sub {
 
 test 'taxes' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     my $rset;
 
@@ -147,7 +190,7 @@ test 'taxes' => sub {
 
 test 'price modifiers' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->price_modifiers->count, '==', 15, "15 price_modifiers" );
 
@@ -156,7 +199,7 @@ test 'price modifiers' => sub {
 
 test 'roles' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->roles->count, '==', 7, "7 roles" );
 
@@ -165,7 +208,7 @@ test 'roles' => sub {
 
 test 'zones' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->zones->count, '>=', 317, "at least 317 zones" );
 
@@ -174,7 +217,7 @@ test 'zones' => sub {
 
 test 'users' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->users->count, '==', 5, "5 users" );
 
@@ -194,7 +237,7 @@ test 'users' => sub {
 
 test 'attributes' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->attributes->count, '==', 4, "4 attributes" );
 
@@ -206,7 +249,7 @@ test 'attributes' => sub {
 
 test 'products' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     my ( $rset, $product );
 
@@ -241,7 +284,11 @@ test 'products' => sub {
     cmp_ok( $product->reviews( { approved => 1, public => 1 } )->count,
         '==', 6, "6 approved and public reviews" );
 
-    cmp_ok( $product->average_rating, "==", 4.25, "average rating is 4.25" );
+    cmp_ok( $product->average_rating, "==", 4.3, "average rating is 4.3" );
+    cmp_ok( $product->average_rating(1), "==", 4.3, "average rating is 4.3" );
+    cmp_ok( $product->average_rating(2), "==", 4.27, "average rating is 4.27" );
+    ok( !defined $self->products->find('os28009')->average_rating,
+        "average rating for sku os28009 is undef" );
 
     lives_ok( sub { $rset = $product->top_reviews }, "get top reviews" );
 
@@ -256,14 +303,14 @@ test 'products' => sub {
 
 test 'inventory' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->inventory->count, "==", 39, "39 products in inventory" );
 };
 
 test 'addresses' => sub {
     my $self   = shift;
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     cmp_ok( $self->addresses->count, '==', 8, "8 addresses" );
 
@@ -292,6 +339,31 @@ test 'addresses' => sub {
         "8 Addresses in DB" );
 };
 
+test 'orders' => sub {
+    my $self   = shift;
+    my $schema = $self->ic6s_schema;
+
+    my $order;
+
+    cmp_ok( $self->orders->count, '==', 1, "1 order" );
+
+    lives_ok( sub { $order = $self->orders->first }, "grab order" );
+
+    cmp_ok( $order->orderlines->count, '==', 2, "2 orderlines" );
+
+
+};
+
+test 'media' => sub {
+    my $self   = shift;
+    my $schema = $self->ic6s_schema;
+
+    cmp_ok( $self->media->count, '==', 51, "51 media items" );
+
+};
+
+
+
 # NOTE: do not place any tests after this final test
 
 test 'cleanup' => sub {
@@ -300,12 +372,22 @@ test 'cleanup' => sub {
     lives_ok( sub { $self->clear_all_fixtures }, "clear_all_fixtures" );
 
     foreach my $class ( keys %classes ) {
-        cmp_ok( $self->schema->resultset($class)->count,
+        cmp_ok( $self->ic6s_schema->resultset($class)->count,
             '==', 0, "0 rows in $class" );
 
         my $has = "has_$classes{$class}";
         ok( !$self->$has, "$has is false" );
     }
+
+    cmp_ok( $self->ic6s_schema->resultset('MediaDisplay')->count, '==', 0,
+        "no media displays" );
+
+    cmp_ok( $self->ic6s_schema->resultset('MediaProduct')->count, '==', 0,
+        "no media product rows" );
+
+    cmp_ok( $self->ic6s_schema->resultset('MediaType')->count, '==', 0,
+        "no media types" );
+
 };
 
 1;
